import greenfoot.World;
import greenfoot.Greenfoot;
import greenfoot.MouseInfo;
import greenfoot.core.WorldHandler;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;
import java.awt.Component;
import java.awt.Container;
import java.awt.Window;
import java.applet.Applet;

/**
 * Screen
 * 
 * @author Taylor Born
 * @version March 2014
 */
public class Screen extends World
{
    private static final int WIDTH  = 600;
    private static final int HEIGHT = 400;
    private static boolean removedFrame;
    
    private double x = 50, y = 50, mx = WIDTH - 50, my = HEIGHT - 50;
    private int step;
    private boolean left;

    public Screen()
    {
        super(WIDTH, HEIGHT, 1);
        Greenfoot.start();
    }
    
    @Override
    public void act()
    {
        super.act();
        if (Greenfoot.mouseMoved(null) || Greenfoot.mouseDragged(null)) {
            MouseInfo mouse = Greenfoot.getMouseInfo();
            mx = mouse.getX();
            my = mouse.getY();
        }
        
        if (++step == 20) {
            if (Math.sqrt(Math.pow(x - mx, 2) + Math.pow(y - my, 2)) > 55) {
                double angle = Math.atan2(my - y, mx - x);
                x += Math.cos(angle) * 50;
                y += Math.sin(angle) * 50;
                
                double angle2 = angle + (left ? Math.PI / 2 : -Math.PI / 2);
                double xx = x + Math.cos(angle2) * 12;
                double yy = y + Math.sin(angle2) * 12;
                
                addObject(new Foot(left, angle), (int)xx, (int)yy);
                left = !left;
            }
            step = 0;
        }
    }
    
    @Override
    public void started()
    {
        if (!removedFrame) {
            try {
                // Wait a bit, since it seems the thread responsible for putting together the nested swing components may not have finished yet
                Thread.currentThread().sleep(500);
            } catch (InterruptedException e)
            {}
            try {
                // See if we are in the GreenFoot IDE
                Class.forName("greenfoot.gui.GreenfootFrame");
            } catch (Exception e) {
                JPanel panel = WorldHandler.getInstance().getWorldCanvas();
                Window w = SwingUtilities.getWindowAncestor(panel);
                trim(w);
                w.pack();
//                 print(w, 0);
            }
            removedFrame = true;
        }
    }
    
//     private void print(Container c, int level)
//     {
//         for (Component comp : c.getComponents()) {
//             for (int i = 0; i < level; i++)
//                 System.out.print("  ");
//             System.out.println(comp.getClass());
//             if (comp instanceof Container)
//                 print((Container)comp, level + 1);
//         }
//     }
    
    private void trim(Container c)
    {
        for (Component comp : c.getComponents()) {
            if (comp instanceof greenfoot.gui.ControlPanel) {
                c.remove(comp);
                trim(c);
                return;
            }
            if (comp instanceof javax.swing.JComponent)
                ((javax.swing.JComponent)comp).setBorder(null);
            if (comp instanceof Container)
                trim((Container)comp);
        }
        if (c instanceof Applet) {
            c.setMinimumSize(new java.awt.Dimension(1, 1));
            ((Applet)c).resize(WIDTH, HEIGHT);
        }
    }
}